==> cscec5b-xell-api-3.0.1-20221201.124507-44-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailsVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场验收明细VO
 *
 * @author generator
 *
 */
public class CheckDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String billCode; // 单据编号
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private String licensePlate; // 车牌号
    private String construction; // 使用单位及部位
    private Integer billState; // 单据状态（审批必须字段）
    private Integer useState; // 推送NC状态，0-未推送，1-已推送
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 单位
    private BigDecimal checkNumsSum; // 验收数量
    private BigDecimal weighNum; // 称重数量
    private BigDecimal deliverNumsSum; // 发货数量
    private BigDecimal nprice; // 无税价格
    private BigDecimal mny; // 无税金额
    private BigDecimal taxrate; // 税率
    private BigDecimal tax; // 税金
    private BigDecimal taxmny; // 含税价格
    private Long orgId; // 组织
    private java.lang.String billStateName; // 单据状态名称
    private java.lang.String useStateName; // 推送NC状态名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5
    private String yzMaterialName; // 云筑材料名称
    private String yzUnit; // 云筑材料单位
    private String yzCheckNumsSum; // 云筑验收数量
    private Boolean sourceType; // 来源, 1-自制, 2-云筑
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注


    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getUseStateName() {
        return useStateName;
    }

    public void setUseStateName(String useStateName) {
        this.useStateName = useStateName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }

    public BigDecimal getWeighNum() {
        return weighNum;
    }

    public void setWeighNum(BigDecimal weighNum) {
        this.weighNum = weighNum;
    }

    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public BigDecimal getTaxmny() {
        return taxmny;
    }

    public void setTaxmny(BigDecimal taxmny) {
        this.taxmny = taxmny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    /**
     * 云筑材料名称
     */
    public String getYzMaterialName() {
        return yzMaterialName;
    }

    /**
     * 云筑材料名称
     */
    public void setYzMaterialName(String yzMaterialName) {
        this.yzMaterialName = yzMaterialName;
    }
    /**
     * 云筑材料单位
     */
    public String getYzUnit() {
        return yzUnit;
    }

    /**
     * 云筑材料单位
     */
    public void setYzUnit(String yzUnit) {
        this.yzUnit = yzUnit;
    }
    /**
     * 云筑验收数量
     */
    public String getYzCheckNumsSum() {
        return yzCheckNumsSum;
    }

    /**
     * 云筑验收数量
     */
    public void setYzCheckNumsSum(String yzCheckNumsSum) {
        this.yzCheckNumsSum = yzCheckNumsSum;
    }
    /**
     * 来源, 1-自制, 2-云筑
     */
    public Boolean getSourceType() {
        return sourceType;
    }

    /**
     * 来源, 1-自制, 2-云筑
     */
    public void setSourceType(Boolean sourceType) {
        this.sourceType = sourceType;
    }

    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}

==> cscec5b-xell-api-3.0.1-20240824.044821-79-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailsVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场验收明细VO
 *
 * @author generator
 *
 */
public class CheckDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String billCode; // 单据编号
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private String licensePlate; // 车牌号
    private String construction; // 使用单位及部位
    private Integer billState; // 单据状态（审批必须字段）
    private Integer useState; // 推送NC状态，0-未推送，1-已推送
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 单位
    private BigDecimal checkNumsSum; // 验收数量
    private BigDecimal weighNum; // 称重数量
    private BigDecimal checkWeighNum; // 验收称重偏差值
    private BigDecimal deliverNumsSum; // 发货数量
    private BigDecimal nprice; // 无税价格
    private BigDecimal mny; // 无税金额
    private BigDecimal taxrate; // 税率
    private BigDecimal tax; // 税金
    private BigDecimal taxmny; // 含税价格
    private Long orgId; // 组织
    private java.lang.String billStateName; // 单据状态名称
    private java.lang.String useStateName; // 推送NC状态名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5
    private String yzMaterialName; // 云筑材料名称
    private String yzUnit; // 云筑材料单位
    private String yzCheckNumsSum; // 云筑验收数量
    private Boolean sourceType; // 来源, 1-自制, 2-云筑
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注


    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getUseStateName() {
        return useStateName;
    }

    public void setUseStateName(String useStateName) {
        this.useStateName = useStateName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }

    public BigDecimal getWeighNum() {
        return weighNum;
    }

    public void setWeighNum(BigDecimal weighNum) {
        this.weighNum = weighNum;
    }

    public BigDecimal getCheckWeighNum() {
        return checkWeighNum;
    }

    public void setCheckWeighNum(BigDecimal checkWeighNum) {
        this.checkWeighNum = checkWeighNum;
    }

    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public BigDecimal getTaxmny() {
        return taxmny;
    }

    public void setTaxmny(BigDecimal taxmny) {
        this.taxmny = taxmny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    /**
     * 云筑材料名称
     */
    public String getYzMaterialName() {
        return yzMaterialName;
    }

    /**
     * 云筑材料名称
     */
    public void setYzMaterialName(String yzMaterialName) {
        this.yzMaterialName = yzMaterialName;
    }
    /**
     * 云筑材料单位
     */
    public String getYzUnit() {
        return yzUnit;
    }

    /**
     * 云筑材料单位
     */
    public void setYzUnit(String yzUnit) {
        this.yzUnit = yzUnit;
    }
    /**
     * 云筑验收数量
     */
    public String getYzCheckNumsSum() {
        return yzCheckNumsSum;
    }

    /**
     * 云筑验收数量
     */
    public void setYzCheckNumsSum(String yzCheckNumsSum) {
        this.yzCheckNumsSum = yzCheckNumsSum;
    }
    /**
     * 来源, 1-自制, 2-云筑
     */
    public Boolean getSourceType() {
        return sourceType;
    }

    /**
     * 来源, 1-自制, 2-云筑
     */
    public void setSourceType(Boolean sourceType) {
        this.sourceType = sourceType;
    }

    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
